# œ.js
## A JavaScript library similar to jQuery, that manipulates the DOM. By the way, this is my first JS library.
[![github muffins](https://img.shields.io/badge/Muffins-1-brightgreen.svg?style=flat)](https://github.com/RailRunner16/oe.js/blob/master)
___
[![GitHub version](https://badge.fury.io/gh/RailRunner16%2Foe.js.svg)](https://badge.fury.io/gh/RailRunner16%2Foe.js)
[![npm version](https://badge.fury.io/js/oe-like-jquery.svg)](https://badge.fury.io/js/oe-like-jquery)
[![npm](https://img.shields.io/npm/l/express.svg)](https://github.com/RailRunner16/oe.js/blob/add-license-1/LICENSE)
___
### CDN for Œ.js:
##### For development:
- Changes to the library are updated within minutes.
- Excessive traffic will be throttled and blacklisted.
- If excessive traffic continues, a prominent error message will be displayed on your website to try to get your attention.
- `<script>` tag for non-minified version:
    ```html
    <script src="https://rawgit.com/RailRunner16/oe.js/master/%C5%93.js" integrity="sha384-sj5i8MOhvDA/zXS26b+m1Kc4YKWcg7GMZGpf46XcWtyGR+X2B3O14WeGI+EW4Dm3" crossorigin="anonymous"></script>
    ```
- `<script>` tag for minified version:
    ```html
    <script src="https://rawgit.com/RailRunner16/oe.js/master/%C5%93.min.js" integrity="sha384-mWzmcwkZyDlBkyyunJIy4HxhtoYcgk1jYslWoB8O9GW+FwDepAbywvz71nTqSX8p" crossorigin="anonymous"></script>
    ```
___
### Selecting a DOM element:
`_œ()` is this library's equivalent to jQuery's `$()`. It can select elements by id with the syntax: `_œ('id')`, just dont put the pound symbol in the id.

###### To get the _œ_ character, do <kbd>rightalt + x</kbd> on an extended U.S. keyboard.
___
### Functions:
#### Standard Functions
- `show()`:
  - Displays a hidden DOM element. If the DOM element is visible already, it will do nothing.
  - Syntax:
    ```javascript
    _œ('selector').show();
    ```
- `hide()`:
  - Hides a visible DOM element. If the DOM element is already hidden, it will do nothing.
  - Syntax:
    ```javascript
    _œ('selector').hide();
    ```
- `on(event, callback)`:
  - This function gives the selected element(s) one or more event handlers. It will work on any element.
  - Syntax:
    ```javascript
    _œ('selector').on(event, function(){
      // Perform your operation here
    });
    ```
- `bgcolor(color)`:
  - This function sets the background of the selected element(s). It will not work on non visible components or components that have been hidden. It can process any type of color values that HTML can. (For example: RGB, RGBA, Hex values all work.)
  - Syntax:
    ```javascript
    _œ('selector').bgcolor(color);
    ```
- `val(newval)`:
  - This function sets the value of the selected element to the specified new value. It only works on elements with the `value` attribute.
  - Syntax
    ```javascript
    _œ('selector').val(new_value);
    ```
- `css(attr, value)`:
  - This function will change any CSS property of a given element. All you have to do is specify the property
and the new value.
  - Syntax:
    ```javascript
    _œ('selector').css(property, newvalue);
    ```
- `size(width, height)`:
  - Changes the size of the selected element. Accepts two parameters: width and height.
  - Syntax:
    ```javascript
    _œ('selector').size(width, height);
    ```
- `width(width)`:
  - Changes the width of the selected element.
  - Syntax:
    ```javascript
    _œ('selector').width(width);
    ```
- `height(height)`:
  - Changes the height of the selected element.
  - Syntax:
    ```javascript
    _œ('selector').height(height);
    ```
- `html(content)`:
  - Changes the inner HTML content of the selected element.
  - Syntax:
    ```javascript
    _œ('selector').html(newcontent);
    ```
- `colAmt(cols)`:
  - Changes the amount of columns the selected element is divided into.
  - Syntax:
    ```javascript
    _œ('selector').colAmt(cols);
    ```
- `decoType(type)`:
  - Changes the type of text decoration that applies to the selected element.
  - Syntax:
    ```javascript
    _œ('selector').decoType(type);
    ```
  - All Valid Types of Text Decoration:
    1. `none`
    2. `underline`
    3. `overline`
    4. `line-through`
    5. `initial`
    6. `inherit`
- `decoColor(color)`:
  - Changes the color of the selected element's text decoration.
  - Syntax:
    ```javascript
    _œ('selector').decoColor(color);
    ```
- `decoStyle(style)`:
  - Changes the style of the selected element's text decoration.
  - Syntax:
    ```javascript
    _œ('selector').decoStyle(style);
    ```
  - All Valid Styles of Text Decoration:
    1. `solid`
    2. `double`
    3. `dotted`
    4. `dashed`
    5. `wavy`
    6. `initial`
    7. `inherit`
- `txtIndent(amount)`:
  - This function changes the size of the text indentation of the selected element. It should be used on text-containing elements only, and the value you set is automatically converted to px.
  - Syntax:
    ```javascript
    _œ('selector').txtIndent(amount);
    ```
- `cursor(type)`:
  - This function will change the cursor to the selected type. A list of types can be found [here](https://www.sitepoint.com/css3-cursor-styles/).  The best practice is usually to put the code inside an event handler.
  - Syntax:
    ```javascript
    _œ(selector).cursor(type);
    ```
#### Event Handlers
- `click(callback)`:
  - This event handler is triggered when the specified object is cicked.
  - Syntax:
    ```javascript
    _œ('selector').click(function(){
      // Callback code goes here.
    });
    ```
- `doubleClick(callback)`:
  - This event handler is triggered when the specified object is cicked twice in a row.
  - Syntax:
    ```javascript
    _œ('selector').doubleClick(function(){
      // Callback code goes here.
    });
    ```
- `mouseWheel(callback)`:
  - This event handler is triggered when the mouse wheel is is being or just has been scrolled.
  - Syntax:
    ```javascript
    _œ('selector').mouseWheel(function(){
      // Callback code goes here.
    });
    ```
- `mouseOver(callback)`:
  - This event handler is triggered when the specified object is being hovered over by the user's cursor.
  - Syntax:
    ```javascript
    _œ('selector').mouseOver(function(){
      // Callback code goes here.
    });
    ```
- `keyDown(callback)`:
  - This event handler is triggered when a key on the keyboard is pressed.
  - Syntax:
    ```javascript
    _œ('selector').keyDown(function(){
      // Callback code goes here.
    });
    ```
- `scroll(callback)`:
  - This event handler is triggered when the UI is scrolled.
  - Syntax:
    ```javascript
    _œ('selector').scroll(function(){
      // Callback code goes here.
    });
    ```
- `animationEnd(callback)`:
  - This event handler is triggered when a CSS animation ends.
  - Syntax:
    ```javascript
    _œ('selector').animationEnd(function(){
      // Callback code goes here.
    });
    ```
- `mouseOut(callback)`:
  - This event handler is triggered when a user moves their cursor out of the selected object.
  - Syntax:
    ```javascript
    _œ('selector').mouseOut(function(){
      // Callback code goes here.
    });
    ```
- `beforeScript(callback)`:
  - This event handler is triggered before the selected script tag executes.
  - Syntax:
    ```javascript
    _œ('selector').beforeScript(function(){
      // Callback code goes here.
    });
    ```
- `afterScript(callback)`:
  - This event handler is triggered after the selected script tag executes.
  - Syntax:
    ```javascript
    _œ('selector').afterScript(function(){
      // Callback code goes here.
    });
    ```
- `beforePrint(callback)`:
  - This event handler is triggered before the print dialogue opens.
  - Syntax:
    ```javascript
    _œ('selector').beforePrint(function(){
      // Callback code goes here.
    });
    ```
- `afterPrint(callback)`:
  - This event handler is triggered after the print dialogue closes.
  - Syntax:
    ```javascript
    _œ('selector').afterPrint(function(){
      // Callback code goes here.
    });
    ```
- `loadResource(callback)`:
  - This event handler is triggered when a resource and its dependent resources have finished loading.
  - It works on any type of external resource.
  - Syntax:
    ```javascript
    _œ('selector').loadResource(function(){
      // Callback code goes here.
    });
    ```
- `transitionRun(callback)`:
  - This event handler is triggered when a CSS transition has began running (fired before any delay starts).
  - Syntax:
    ```javascript
    _œ('selector').transitionRun(function(){
      // Callback code goes here.
    });
    ```
- `transitionStart(callback)`:
  - This event handler is triggered when a CSS transition has actually started (fired after any delay).
  - Syntax:
    ```javascript
    _œ('selector').transitionStart(function(){
      // Callback code goes here.
    });
    ```
- `transitionCancel(callback)`:
  - This event handler is triggered when a CSS transition has been cancelled.
  - Syntax:
    ```javascript
    _œ('selector').transitionCancel(function(){
      // Callback code goes here.
    });
    ```
- `transitionEnd(callback)`:
  - This event handler is triggered when a CSS transition has completed.
  - Syntax:
    ```javascript
    _œ('selector').transitionEnd(function(){
      // Callback code goes here.
    });
    ```
- `browserOnline(callback)`:
  - This event handler is triggered when the browser connects to the network.
  - Syntax:
    ```javascript
    _œ('selector').browserOnline(function(){
      // Callback code goes here.
    });
    ```
- `browserOffline(callback)`:
  - This event handler is triggered when the browser disconnects from the network.
  - Syntax:
    ```javascript
    _œ('selector').browserOffline(function(){
      // Callback code goes here.
    });
    ```
- `formReset(callback)`:
  - This event handler is triggered when a form's "reset" button has been pressed.
  - Syntax:
    ```javascript
    _œ('selector').formReset(function(){
      // Callback code goes here.
    });
    ```
- `formSubmit(callback)`:
  - This event handler is triggered when a forms "submit" button has been pressed.
  - Syntax:
    ```javascript
    _œ('selector').transitionEnd(function(){
      // Callback code goes here.
    });
    ```